@@ -51,6 +51,9 @@ void ShowSceneCollectionManagerDialog()
 void SceneCollectionManagerHotkey(void *data, obs_hotkey_id id,
 				  obs_hotkey_t *hotkey, bool pressed)
 {
+	UNUSED_PARAMETER(data);
+	UNUSED_PARAMETER(id);
+	UNUSED_PARAMETER(hotkey);
 	if (!pressed)
 		return;
 
@@ -98,6 +101,8 @@ static void BackupSceneCollection()
 	if (!currentSceneCollection || strlen(currentSceneCollection) < 1)
 		return;
 
+	obs_frontend_save();
+
 	std::string currentSafeName;
 	if (!GetFileSafeName(currentSceneCollection, currentSafeName))
 		return;
@@ -138,6 +143,9 @@ static void BackupSceneCollection()
 void BackupSceneCollectionHotkey(void *data, obs_hotkey_id id,
 				 obs_hotkey_t *hotkey, bool pressed)
 {
+	UNUSED_PARAMETER(data);
+	UNUSED_PARAMETER(id);
+	UNUSED_PARAMETER(hotkey);
 	if (!pressed)
 		return;
 
@@ -179,6 +187,24 @@ std::string GetBackupDirectory(std::string filename)
 	return dir;
 }
 
+bool activate_dshow_proc(void *p, obs_source_t *source)
+{
+	if (strcmp(obs_source_get_unversioned_id(source), "dshow_input") != 0)
+		return true;
+	const bool active = *(bool *)p;
+	calldata_t cd = {};
+	calldata_set_bool(&cd, "active", active);
+	proc_handler_t *ph = obs_source_get_proc_handler(source);
+	proc_handler_call(ph, "activate", &cd);
+	calldata_free(&cd);
+	return true;
+}
+
+void activate_dshow(bool active)
+{
+	obs_enum_sources(activate_dshow_proc, &active);
+}
+
 void LoadBackupSceneCollection(const std::string sceneCollection,
 			       const std::string filename,
 			       const std::string backupFile)
@@ -191,6 +217,7 @@ void LoadBackupSceneCollection(const std::string sceneCollection,
 	obs_data_set_string(data, "name", sceneCollection.c_str());
 	obs_data_save_json_safe(data, filename.c_str(), "tmp", "bak");
 	obs_data_release(data);
+	activate_dshow(false);
 	if (strcmp(obs_frontend_get_current_scene_collection(),
 		   sceneCollection.c_str()) == 0) {
 		config_set_string(obs_frontend_get_global_config(), "Basic",
@@ -207,6 +234,7 @@ void LoadBackupSceneCollection(const std::string sceneCollection,
 		obs_frontend_set_current_scene_collection(
 			sceneCollection.c_str());
 	}
+	activate_dshow(true);
 }
 
 void LoadBackupSceneCollection(bool last)
@@ -236,8 +264,7 @@ void LoadBackupSceneCollection(bool last)
 		if (glob->gl_pathv[i].directory)
 			continue;
 
-		struct stat stats {
-		};
+		struct stat stats {};
 		if (os_stat(filePath, &stats) == 0 && stats.st_size > 0) {
 			if (last) {
 				if (time == 0 || stats.st_ctime >= time) {
@@ -260,6 +287,9 @@ void LoadBackupSceneCollection(bool last)
 void LoadLastBackupSceneCollectionHotkey(void *data, obs_hotkey_id id,
 					 obs_hotkey_t *hotkey, bool pressed)
 {
+	UNUSED_PARAMETER(data);
+	UNUSED_PARAMETER(id);
+	UNUSED_PARAMETER(hotkey);
 	if (!pressed)
 		return;
 	const auto main =
@@ -272,6 +302,9 @@ void LoadLastBackupSceneCollectionHotkey(void *data, obs_hotkey_id id,
 void LoadFirstBackupSceneCollectionHotkey(void *data, obs_hotkey_id id,
 					  obs_hotkey_t *hotkey, bool pressed)
 {
+	UNUSED_PARAMETER(data);
+	UNUSED_PARAMETER(id);
+	UNUSED_PARAMETER(hotkey);
 	if (!pressed)
 		return;
 	const auto main =
@@ -428,7 +461,7 @@ void SceneCollectionManagerDialog::RefreshSceneCollections()
 						 ui->sceneCollectionList);
 		ui->sceneCollectionList->addItem(item);
 		if (scene_collection.first == current_scene_collection) {
-			ui->sceneCollectionList->setItemSelected(item, true);
+			item->setSelected(true);
 			ui->sceneCollectionList->setCurrentItem(item);
 		}
 	}
@@ -437,6 +470,7 @@ void SceneCollectionManagerDialog::RefreshSceneCollections()
 void SceneCollectionManagerDialog::on_searchSceneCollectionEdit_textChanged(
 	const QString &text)
 {
+	UNUSED_PARAMETER(text);
 	RefreshSceneCollections();
 }
 
@@ -831,12 +865,26 @@ void SceneCollectionManagerDialog::on_actionRemoveSceneCollection_triggered()
 	if (reinterpret_cast<QAbstractButton *>(yes) != remove.clickedButton())
 		return;
 	for (auto &item : items) {
-		const auto filePath = scene_collections.at(item->text());
+		auto filePath = scene_collections.at(item->text());
 		if (filePath.length() == 0)
 			continue;
-
+		filePath = os_get_abs_path_ptr(filePath.c_str());
 		os_unlink(filePath.c_str());
-		os_rmdir(GetBackupDirectory(filePath).c_str());
+		auto backupDir = GetBackupDirectory(filePath);
+		const auto f = backupDir + "*.json";
+		os_glob_t *glob;
+		if (os_glob(f.c_str(), 0, &glob) == 0) {
+			for (size_t i = 0; i < glob->gl_pathc; i++) {
+				const char *backupFilePath =
+					glob->gl_pathv[i].path;
+
+				if (glob->gl_pathv[i].directory)
+					continue;
+				os_unlink(backupFilePath);
+			}
+			os_globfree(glob);
+		}
+		os_rmdir(backupDir.c_str());
 		scene_collections.erase(item->text());
 	}
 	RefreshSceneCollections();
@@ -958,7 +1006,9 @@ void SceneCollectionManagerDialog::on_actionSwitchSceneCollection_triggered()
 	if (const auto item = ui->sceneCollectionList->currentItem()) {
 		auto t = item->text().toUtf8();
 		auto c = t.constData();
+		activate_dshow(false);
 		obs_frontend_set_current_scene_collection(c);
+		activate_dshow(true);
 	}
 }
 
@@ -1059,9 +1109,8 @@ void SceneCollectionManagerDialog::on_actionConfigBackup_triggered()
 	connect(a, &QAction::triggered, [] {
 		autoSaveBackup = !autoSaveBackup;
 		const auto config = obs_frontend_get_global_config();
-		config_set_bool(obs_frontend_get_global_config(),
-				"SceneCollectionManager", "AutoSaveBackup",
-				autoSaveBackup);
+		config_set_bool(config, "SceneCollectionManager",
+				"AutoSaveBackup", autoSaveBackup);
 	});
 
 	auto dirMenu =
@@ -1237,6 +1286,7 @@ void SceneCollectionManagerDialog::on_sceneCollectionList_currentRowChanged(
 void SceneCollectionManagerDialog::on_sceneCollectionList_itemDoubleClicked(
 	QListWidgetItem *item)
 {
+	UNUSED_PARAMETER(item);
 	QMetaObject::invokeMethod(this,
 				  "on_actionSwitchSceneCollection_triggered",
 				  Qt::QueuedConnection);
@@ -1245,6 +1295,7 @@ void SceneCollectionManagerDialog::on_sceneCollectionList_itemDoubleClicked(
 void SceneCollectionManagerDialog::on_backupList_itemDoubleClicked(
 	QListWidgetItem *item)
 {
+	UNUSED_PARAMETER(item);
 	QMetaObject::invokeMethod(this, "on_actionSwitchBackup_triggered",
 				  Qt::QueuedConnection);
 }
